package com.caimei365.manager.controller.caimei.keyword;

import com.alibaba.excel.EasyExcel;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmPriorKeyword;
import com.caimei365.manager.entity.caimei.KeyWord;
import com.caimei365.manager.entity.caimei.cmUser.ServiceProviderModel;
import com.caimei365.manager.service.caimei.KeyWordService;
import com.caimei365.manager.service.caimei.listener.KeywordListener;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;


/**
 * @author zzj
 * 用户关键词/标签库
 */
@RestController
@RequestMapping("/keyword")
public class KeyWordApi {

    @Resource
    private KeyWordService keyWordService;

    @Resource
    private KeywordListener keywordListener;

    /**
     * 关键词列表
     * keyword 关键词
     * searchTimeCode 近一年 近半年 近一个月 近一周 昨天  默认一年
     * beginTime  自定义时间查询起始时间
     * endTime    自定义时间查询终止时间
     * labelStatus  标签库状态 0未添加 1已添加 传1即是标签列表
     * fromSearch 标签库数据来源（1：手动添加；2：用户关键词统计；3：导入 4：协销填写）
     */
    @GetMapping("/keyword/list")
    public ResponseJson<PaginationVo<KeyWord>> getKeyWordList(String keyword, String beginTime, String endTime,
                                                              Integer labelStatus, Integer fromSearch,
                                                              @RequestParam(value = "searchTimeCode", defaultValue = "1") Integer searchTimeCode,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return keyWordService.getKeyWordList(keyword, searchTimeCode, fromSearch, beginTime, endTime, labelStatus, pageNum, pageSize);
    }

    /**
     * 标签库是否支持联动搜索
     *
     * @param id
     * @return
     */
    @GetMapping("/findLinkageStatus")
    public ResponseJson findLinkageStatus(String id, Integer linkageStatus) {
        return keyWordService.findLinkageStatus(id, linkageStatus);
    }

    /**
     * 加入标签库
     *
     * @param id
     * @return
     */
    @GetMapping("/join/label")
    public ResponseJson joinLabel(String id) {
        return keyWordService.joinLabel(id);
    }

    /**
     * 关键词推荐列表
     *
     * @return
     */
    @GetMapping("/recommend/list")
    public ResponseJson<PaginationVo<KeyWord>> getRecommendList(String keyword, String beginTime, String endTime,
                                                                @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return keyWordService.getRecommendList(keyword, beginTime, endTime, pageNum, pageSize);
    }

    /**
     * 关键词推荐列表忽略
     *
     * @param id
     * @return
     */
    @GetMapping("/ignore/label")
    public ResponseJson ignoreLabel(String id) {
        return keyWordService.ignoreLabel(id);
    }

    /**
     * 手动加入标签库
     *
     * @param keyword
     * @return
     */
    @GetMapping("/insert/label")
    public ResponseJson insertLabel(KeyWord keyword) {
        return keyWordService.insertLabel(keyword);
    }

    /**
     * 导入标签
     *
     * @param keywordFile
     * @return
     */
    @PostMapping("/import/label")
    public ResponseJson doImport(MultipartFile keywordFile) {
        try {
            InputStream inputStream = keywordFile.getInputStream();
            EasyExcel.read(inputStream, KeyWord.class, keywordListener).sheet().doRead();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return ResponseJson.success();
    }

    /**
     * 删除标签
     *
     * @param id
     * @return
     */
    @GetMapping("/delete/label")
    public ResponseJson delLabel(String id) {
        return keyWordService.deleteLabel(id);
    }

    /**
     * 协销列表
     * @return
     */
    @GetMapping("/getServiceList")
    public ResponseJson<List<ServiceProviderModel>> getServiceList() { return keyWordService.getServiceList(); }

    /**
     * 静态标签列表
     * keyword 关键词
     * beginTime  自定义时间查询起始时间
     * endTime    自定义时间查询终止时间
     * labelStatus  标签库状态 0未添加 1已添加 传1即是标签列表
     * fromSearch 标签库数据来源（1：手动添加；2：用户关键词统计；3：导入 4：协销填写）
     */
    @GetMapping("/statekeyword/list")
    public ResponseJson<PaginationVo<KeyWord>> getStateKeyWordList(String keyword, String beginTime, String endTime,
                                                                   Integer fromSearch,  Integer serviceProviderId,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return keyWordService.getStateKeyWordList(keyword, fromSearch, beginTime, endTime, serviceProviderId, pageNum, pageSize);
    }

    /**
     * 保存静态标签
     * @param keyword
     * @return
     */
    @GetMapping("/saveLabelByState")
    public ResponseJson saveLabelByState(String keyword) {
        if (StringUtils.isBlank(keyword)) {
            return ResponseJson.error(-1, "标签不能为空", null);
        }
        return keyWordService.insertLabelByState(keyword);
    }

    /**
     * 优先展示标签列表
     * @param keyword
     * @param fromSearch
     * @param dynamicStatus
     * @param pageNum
     * @param pageSize
     * @return
     */
     @GetMapping("/getPriorKeywordList")
     public ResponseJson<PaginationVo<CmPriorKeyword>> getPriorKeywordList(String keyword, Integer fromSearch, Integer dynamicStatus,
                                                                           @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                           @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {

        return keyWordService.getPriorKeywordList(keyword, fromSearch, dynamicStatus, pageNum, pageSize);
     }

    /**
     * 选择标签
     * @param keyword
     * @param fromSearch
     * @param dynamicStatus 0 为动态标签 1 静态标签
     * @param pageNum
     * @param pageSize
     * @return
     */
     @GetMapping("/getPickKeyword")
     public ResponseJson<PaginationVo<KeyWord>> getPickKeyword(String keyword, Integer fromSearch, Integer dynamicStatus,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {

         return keyWordService.getPickKeyword(keyword, fromSearch, dynamicStatus, pageNum, pageSize);
     }

    /**
     * 保存优先展示标签
     * @param searchIds
     * @return
     */
     @GetMapping("/savePriorKeyword")
     public ResponseJson savePriorKeyword(String searchIds) {
        if (StringUtils.isBlank(searchIds)) {
            return ResponseJson.error(-1, "需优先展示的标签不能为空", null);
        }
        return keyWordService.savePriorKeyword(searchIds);
     }

    /**
     * 删除优先展示标签
     * @param ids
     * @return
     */
     @GetMapping("/delPriorKeyword")
     public ResponseJson delPriorKeyword(String ids) {
         if ( StringUtils.isBlank(ids)) {
             return ResponseJson.error(-1, "Id不能为空", null);
         }
         return keyWordService.delPriorKeyword(ids);
     }
}
