package com.caimei365.manager.dao.user;

import com.caimei365.manager.entity.caimei.cmUser.*;
import com.caimei365.manager.entity.caimei.product.Product;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/7
 */
@Mapper
public interface CmClubRemarksDao {
    /**
     * 协销数据
     * @return
     */
    List<ServiceProviderModel> getServiceList();

    /**
     * 协销已注册用户数
     * @param serviceProviderId
     * @return
     */
    Integer getRegisteredNumber(@Param("serviceProviderId") Integer serviceProviderId,@Param("addTime") String addTime);

    /**
     * 协销未注册用户数
     * @param serviceProviderId
     * @return
     */
    Integer getUnregisteredNumber(@Param("serviceProviderId") Integer serviceProviderId, @Param("addTime") String addTime);

    /**
     * 咨询记录类别
     * @return
     */
    List<CmConsulttype> getClassName();
    /**
     * 已注册用户咨询记录
     * @param cmClubRemarks
     * @return
     */
    List<CmClubRemarks> findRegistList(CmClubRemarks cmClubRemarks);

    /**
     * 根据商品Id 查询商品信息
     * @param productId
     * @return
     */
    List<Product> getProduct(@Param("productId") Integer productId);

    /**
     * 根据id查询报备记录
     * @param reportId
     * @return
     */
    List<CmReport> getReportById(@Param("reportId") Integer reportId);

    /**
     * 咨询类别
     * @param id
     * @return
     */
    String findClassName(String id);

    /**
     * 图片信息
     * @param remarksId
     * @return
     */
    List<String> getRemarksImageList(Integer remarksId);

    /**
     * 文件信息
     * @param remarksId
     * @return
     */
    List<RemarksFileVo> getRemarksFileList(Integer remarksId);

    /**
     * 报备列表
     * @param cmReport
     * @return
     */
    List<CmReport> getReportList(CmReport cmReport);

    /**
     * 已注册用户咨询记录数
     * @param reportId
     * @return
     */
    Integer clubRemarksConut(Integer reportId);

    /**
     * 未注册用户咨询记录数
     * @param reportId
     * @return
     */
    Integer visitorRemarksConut(Integer reportId);

    /**
     * 已注册咨询记录取消关联
     * @param remarksId
     */
    void updateClubRemarks(Integer remarksId);

    /**
     * 未注册咨询记录取消关联
     * @param remarksId
     */
    void updateVisitorRemarks(Integer remarksId);

    /**
     * 删除报备记录
     * @param reportId
     */
    void deleteClubRemarks(Integer reportId);

    /**
     * 审核报备记录
     * @param reportId
     * @param auditName
     * @param auditText
     * @param status
     */
    void updateAuditRemarks(@Param("reportId") Integer reportId, @Param("auditName") String auditName, @Param("auditText") String auditText, @Param("status") Integer status);

    /**
     * 咨询记录类别
     * @param cmConsulttype
     * @return
     */
    List<CmConsulttype> getConsultList(CmConsulttype cmConsulttype);

    /**
     * 添加咨询记录类别
     * @param cmConsulttype
     */
    void insertConsult(CmConsulttype cmConsulttype);

    /**
     * 修改咨询记录类别
     * @param cmConsulttype
     */
    void updateConsult(CmConsulttype cmConsulttype);

    /**
     * 删除咨询记录类别
     * @param id
     */
    void deleteConsult(@Param("id") Integer id);

    /**
     * 未注册咨询记录列表
     * @param visitRemarkVo
     * @return
     */
    List<VisitRemarkVo> getVisitRemarkList(VisitRemarkVo visitRemarkVo);

    /**
     * 未注册用户已同步数据详情
     * @param visitRemarkVo
     * @return
     */
    List<CmClubRemarks> getClubRemarksList(VisitRemarkVo visitRemarkVo);

    /**
     * 未注册用户图片信息
     * @param remarksId
     * @return
     */
    List<String> getVisitorImageList(Integer remarksId);

    /**
     * 未注册用户文件信息
     * @param remarksId
     * @return
     */
    List<RemarksFileVo> getVisitorFileList(Integer remarksId);
}
